@@ -475,7 +475,7 @@
 /* #undef HAVE_BSD_SIGNALS */
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
-/* #undef HAVE_ERR_remove_thread_state */
+#define HAVE_ERR_remove_thread_state 1
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
@@ -601,8 +601,8 @@
 #define HAVE_CHARSET_utf32 1
 #define HAVE_UCA_COLLATIONS 1
 #define HAVE_COMPRESS 1
-/* #undef HAVE_EncryptAes128Ctr */
-/* #undef HAVE_EncryptAes128Gcm */
+#define HAVE_EncryptAes128Ctr 1
+#define HAVE_EncryptAes128Gcm 1
 
 /*
   Stuff that always need to be defined (compile breaks without it)
